bit_width_for_range

Function bit_width_for_range 

pub fn bit_width_for_range(min: i64, max: i64) -> u8
Compute the minimum number of bits needed to represent the range of values.

Useful for external callers that want to estimate compression ratio.