pub fn uncompressed_size(data: &[u8]) -> Result<usize, CodecError>Expand description
Get the uncompressed size from the header without decompressing.
pub fn uncompressed_size(data: &[u8]) -> Result<usize, CodecError>Get the uncompressed size from the header without decompressing.